==> scalarx_2.10-0.2.1-JS.jar: rx/ops/0003-Async$$anonfun$ping$1.js <==
/** @constructor */
ScalaJS.c.rx_ops_Async$$anonfun$ping$1 = (function() {
  ScalaJS.c.scala_runtime_AbstractFunction1.call(this);
  this.$$outer$2 = null;
  this.p$1$2 = null;
  this.stamp$1$f = ScalaJS.modules.scala_scalajs_runtime_Long().zero__Lscala_scalajs_runtime_Long()
});
ScalaJS.c.rx_ops_Async$$anonfun$ping$1.prototype = new ScalaJS.inheritable.scala_runtime_AbstractFunction1();
ScalaJS.c.rx_ops_Async$$anonfun$ping$1.prototype.constructor = ScalaJS.c.rx_ops_Async$$anonfun$ping$1;
ScalaJS.c.rx_ops_Async$$anonfun$ping$1.prototype.apply__Lscala_util_Try__O = (function(x) {
  var set = this.$$outer$2.state__Lrx_core_SpinSet().spinSetOpt__Lscala_Function1__Z(new ScalaJS.classes.scala_scalajs_js_runtime_AnonFunction1((function(arg$outer, x$1) {
    return (function(oldState) {
      if (((!ScalaJS.anyRefEqEq(x$1, ScalaJS.as.rx_ops_Incrementing$SpinState(arg$outer.rx$ops$Async$$anonfun$$$outer__Lrx_ops_Async().state__Lrx_core_SpinSet().apply__O()).value__Lscala_util_Try())) && (arg$outer.stamp$1$f.$$greater$eq__Lscala_scalajs_runtime_Long__Z(oldState.timestamp__J()) || (!arg$outer.rx$ops$Async$$anonfun$$$outer__Lrx_ops_Async().rx$ops$Async$$discardLate$f)))) {
        return new ScalaJS.c.scala_Some().init___O(new ScalaJS.c.rx_ops_Incrementing$SpinState().init___Lrx_ops_Incrementing__J__Lscala_util_Try(arg$outer.rx$ops$Async$$anonfun$$$outer__Lrx_ops_Async(), arg$outer.stamp$1$f, x$1))
      } else {
        return ScalaJS.modules.scala_None()
      }
    })
  })(this, x)));
  if (set) {
    return this.$$outer$2.propagate__Lrx_core_Propagator__O(this.p$1$2)
  } else {
    return ScalaJS.modules.scala_runtime_BoxedUnit().UNIT__Lscala_runtime_BoxedUnit()
  }
});
ScalaJS.c.rx_ops_Async$$anonfun$ping$1.prototype.rx$ops$Async$$anonfun$$$outer__Lrx_ops_Async = (function() {
  return this.$$outer$2
});
ScalaJS.c.rx_ops_Async$$anonfun$ping$1.prototype.apply__O__O = (function(v1) {
  return this.apply__Lscala_util_Try__O(ScalaJS.as.scala_util_Try(v1))
});
ScalaJS.c.rx_ops_Async$$anonfun$ping$1.prototype.init___Lrx_ops_Async__Lrx_core_Propagator__J = (function($$outer, p$1, stamp$1) {
  if (($$outer === null)) {
    throw new ScalaJS.c.java_lang_NullPointerException().init___()
  } else {
    this.$$outer$2 = $$outer
  };
  this.p$1$2 = p$1;
  this.stamp$1$f = stamp$1;
  ScalaJS.c.scala_runtime_AbstractFunction1.prototype.init___.call(this);
  return this
});
ScalaJS.c.rx_ops_Async$$anonfun$ping$1.prototype.apply = (function(arg$1) {
  if (ScalaJS.is.scala_util_Try(arg$1)) {
    return this.apply__Lscala_util_Try__O(arg$1)
  } else {
    if (ScalaJS.is.java_lang_Object(arg$1)) {
      return this.apply__O__O(arg$1)
    } else {
      throw "No matching overload"
    }
  }
});
ScalaJS.c.rx_ops_Async$$anonfun$ping$1.prototype.rx$ops$Async$$anonfun$$$outer = (function() {
  return this.rx$ops$Async$$anonfun$$$outer__Lrx_ops_Async()
});
ScalaJS.c.rx_ops_Async$$anonfun$ping$1.prototype.rx$ops$Async$$anonfun$$$outer__ = (function() {
  return this.rx$ops$Async$$anonfun$$$outer__Lrx_ops_Async()
});
ScalaJS.c.rx_ops_Async$$anonfun$ping$1.prototype.apply__Lscala_util_Try__ = (function(x) {
  return this.apply__Lscala_util_Try__O(x)
});
/** @constructor */
ScalaJS.inheritable.rx_ops_Async$$anonfun$ping$1 = (function() {
  /*<skip>*/
});
ScalaJS.inheritable.rx_ops_Async$$anonfun$ping$1.prototype = ScalaJS.c.rx_ops_Async$$anonfun$ping$1.prototype;
/** @constructor */
ScalaJS.classes.rx_ops_Async$$anonfun$ping$1 = (function(arg$1, arg$2, arg$3) {
  ScalaJS.c.rx_ops_Async$$anonfun$ping$1.call(this);
  return this.init___Lrx_ops_Async__Lrx_core_Propagator__J(arg$1, arg$2, arg$3)
});
ScalaJS.classes.rx_ops_Async$$anonfun$ping$1.prototype = ScalaJS.c.rx_ops_Async$$anonfun$ping$1.prototype;
ScalaJS.is.rx_ops_Async$$anonfun$ping$1 = (function(obj) {
  return (!(!((obj && obj.$classData) && obj.$classData.ancestors.rx_ops_Async$$anonfun$ping$1)))
});
ScalaJS.as.rx_ops_Async$$anonfun$ping$1 = (function(obj) {
  if ((ScalaJS.is.rx_ops_Async$$anonfun$ping$1(obj) || (obj === null))) {
    return obj
  } else {
    ScalaJS.throwClassCastException(obj, "rx.ops.Async$$anonfun$ping$1")
  }
});
ScalaJS.isArrayOf.rx_ops_Async$$anonfun$ping$1 = (function(obj, depth) {
  return (!(!(((obj && obj.$classData) && (obj.$classData.arrayDepth === depth)) && obj.$classData.arrayBase.ancestors.rx_ops_Async$$anonfun$ping$1)))
});
ScalaJS.asArrayOf.rx_ops_Async$$anonfun$ping$1 = (function(obj, depth) {
  if ((ScalaJS.isArrayOf.rx_ops_Async$$anonfun$ping$1(obj, depth) || (obj === null))) {
    return obj
  } else {
    ScalaJS.throwArrayCastException(obj, "Lrx.ops.Async$$anonfun$ping$1;", depth)
  }
});
ScalaJS.data.rx_ops_Async$$anonfun$ping$1 = new ScalaJS.ClassTypeData({
  rx_ops_Async$$anonfun$ping$1: 0
}, false, "rx.ops.Async$$anonfun$ping$1", ScalaJS.data.scala_runtime_AbstractFunction1, {
  rx_ops_Async$$anonfun$ping$1: 1,
  scala_Serializable: 1,
  java_io_Serializable: 1,
  scala_runtime_AbstractFunction1: 1,
  scala_Function1: 1,
  java_lang_Object: 1
});
ScalaJS.c.rx_ops_Async$$anonfun$ping$1.prototype.$classData = ScalaJS.data.rx_ops_Async$$anonfun$ping$1;
//@ sourceMappingURL=0003-Async$$anonfun$ping$1.js.map

==> scalarx_2.10-0.2.2-JS.jar: rx/ops/0003-Async$$anonfun$ping$1.js <==
/** @constructor */
ScalaJS.c.rx_ops_Async$$anonfun$ping$1 = (function() {
  ScalaJS.c.scala_runtime_AbstractFunction1.call(this);
  this.$$outer$2 = null;
  this.p$1$2 = null;
  this.stamp$1$f = ScalaJS.modules.scala_scalajs_runtime_Long().zero__Lscala_scalajs_runtime_Long()
});
ScalaJS.c.rx_ops_Async$$anonfun$ping$1.prototype = new ScalaJS.inheritable.scala_runtime_AbstractFunction1();
ScalaJS.c.rx_ops_Async$$anonfun$ping$1.prototype.constructor = ScalaJS.c.rx_ops_Async$$anonfun$ping$1;
ScalaJS.c.rx_ops_Async$$anonfun$ping$1.prototype.apply__Lscala_util_Try__O = (function(x) {
  var set = this.$$outer$2.state__Lrx_core_SpinSet().spinSetOpt__Lscala_Function1__Z(new ScalaJS.classes.scala_scalajs_js_runtime_AnonFunction1((function(arg$outer, x$1) {
    return (function(oldState) {
      if (((!ScalaJS.anyRefEqEq(x$1, ScalaJS.as.rx_core_Incrementing$SpinState(arg$outer.rx$ops$Async$$anonfun$$$outer__Lrx_ops_Async().state__Lrx_core_SpinSet().apply__O()).value__Lscala_util_Try())) && (arg$outer.stamp$1$f.$$greater$eq__Lscala_scalajs_runtime_Long__Z(oldState.timestamp__J()) || (!arg$outer.rx$ops$Async$$anonfun$$$outer__Lrx_ops_Async().rx$ops$Async$$discardLate$f)))) {
        return new ScalaJS.c.scala_Some().init___O(new ScalaJS.c.rx_core_Incrementing$SpinState().init___Lrx_core_Incrementing__J__Lscala_util_Try(arg$outer.rx$ops$Async$$anonfun$$$outer__Lrx_ops_Async(), arg$outer.stamp$1$f, x$1))
      } else {
        return ScalaJS.modules.scala_None()
      }
    })
  })(this, x)));
  if (set) {
    return this.$$outer$2.propagate__Lrx_core_Propagator__O(this.p$1$2)
  } else {
    return ScalaJS.modules.scala_runtime_BoxedUnit().UNIT__Lscala_runtime_BoxedUnit()
  }
});
ScalaJS.c.rx_ops_Async$$anonfun$ping$1.prototype.rx$ops$Async$$anonfun$$$outer__Lrx_ops_Async = (function() {
  return this.$$outer$2
});
ScalaJS.c.rx_ops_Async$$anonfun$ping$1.prototype.apply__O__O = (function(v1) {
  return this.apply__Lscala_util_Try__O(ScalaJS.as.scala_util_Try(v1))
});
ScalaJS.c.rx_ops_Async$$anonfun$ping$1.prototype.init___Lrx_ops_Async__Lrx_core_Propagator__J = (function($$outer, p$1, stamp$1) {
  if (($$outer === null)) {
    throw new ScalaJS.c.java_lang_NullPointerException().init___()
  } else {
    this.$$outer$2 = $$outer
  };
  this.p$1$2 = p$1;
  this.stamp$1$f = stamp$1;
  ScalaJS.c.scala_runtime_AbstractFunction1.prototype.init___.call(this);
  return this
});
ScalaJS.c.rx_ops_Async$$anonfun$ping$1.prototype.apply = (function(arg$1) {
  if (ScalaJS.is.scala_util_Try(arg$1)) {
    return this.apply__Lscala_util_Try__O(arg$1)
  } else {
    if (ScalaJS.is.java_lang_Object(arg$1)) {
      return this.apply__O__O(arg$1)
    } else {
      throw "No matching overload"
    }
  }
});
ScalaJS.c.rx_ops_Async$$anonfun$ping$1.prototype.rx$ops$Async$$anonfun$$$outer = (function() {
  return this.rx$ops$Async$$anonfun$$$outer__Lrx_ops_Async()
});
ScalaJS.c.rx_ops_Async$$anonfun$ping$1.prototype.rx$ops$Async$$anonfun$$$outer__ = (function() {
  return this.rx$ops$Async$$anonfun$$$outer__Lrx_ops_Async()
});
ScalaJS.c.rx_ops_Async$$anonfun$ping$1.prototype.apply__Lscala_util_Try__ = (function(x) {
  return this.apply__Lscala_util_Try__O(x)
});
/** @constructor */
ScalaJS.inheritable.rx_ops_Async$$anonfun$ping$1 = (function() {
  /*<skip>*/
});
ScalaJS.inheritable.rx_ops_Async$$anonfun$ping$1.prototype = ScalaJS.c.rx_ops_Async$$anonfun$ping$1.prototype;
/** @constructor */
ScalaJS.classes.rx_ops_Async$$anonfun$ping$1 = (function(arg$1, arg$2, arg$3) {
  ScalaJS.c.rx_ops_Async$$anonfun$ping$1.call(this);
  return this.init___Lrx_ops_Async__Lrx_core_Propagator__J(arg$1, arg$2, arg$3)
});
ScalaJS.classes.rx_ops_Async$$anonfun$ping$1.prototype = ScalaJS.c.rx_ops_Async$$anonfun$ping$1.prototype;
ScalaJS.is.rx_ops_Async$$anonfun$ping$1 = (function(obj) {
  return (!(!((obj && obj.$classData) && obj.$classData.ancestors.rx_ops_Async$$anonfun$ping$1)))
});
ScalaJS.as.rx_ops_Async$$anonfun$ping$1 = (function(obj) {
  if ((ScalaJS.is.rx_ops_Async$$anonfun$ping$1(obj) || (obj === null))) {
    return obj
  } else {
    ScalaJS.throwClassCastException(obj, "rx.ops.Async$$anonfun$ping$1")
  }
});
ScalaJS.isArrayOf.rx_ops_Async$$anonfun$ping$1 = (function(obj, depth) {
  return (!(!(((obj && obj.$classData) && (obj.$classData.arrayDepth === depth)) && obj.$classData.arrayBase.ancestors.rx_ops_Async$$anonfun$ping$1)))
});
ScalaJS.asArrayOf.rx_ops_Async$$anonfun$ping$1 = (function(obj, depth) {
  if ((ScalaJS.isArrayOf.rx_ops_Async$$anonfun$ping$1(obj, depth) || (obj === null))) {
    return obj
  } else {
    ScalaJS.throwArrayCastException(obj, "Lrx.ops.Async$$anonfun$ping$1;", depth)
  }
});
ScalaJS.data.rx_ops_Async$$anonfun$ping$1 = new ScalaJS.ClassTypeData({
  rx_ops_Async$$anonfun$ping$1: 0
}, false, "rx.ops.Async$$anonfun$ping$1", ScalaJS.data.scala_runtime_AbstractFunction1, {
  rx_ops_Async$$anonfun$ping$1: 1,
  scala_Serializable: 1,
  java_io_Serializable: 1,
  scala_runtime_AbstractFunction1: 1,
  scala_Function1: 1,
  java_lang_Object: 1
});
ScalaJS.c.rx_ops_Async$$anonfun$ping$1.prototype.$classData = ScalaJS.data.rx_ops_Async$$anonfun$ping$1;
//@ sourceMappingURL=0003-Async$$anonfun$ping$1.js.map
